/* 
 * tplay - buffered audio player
 *
 * (c) 1997 ilkka karvinen <ik@iki.fi>
 *
 * Copyright under the GNU GENERAL PUBLIC LICENSE
 *   (see the file COPYING in this directory)
 *
 * 
 *   common functions for audio
 */

#include <stropts.h>
#include <sys/audioio.h>
#include "common.h"
#include "audio_sun.h"

struct info_struct info;

void open_audio()
{
  /* Set audio block size and number of blocks */
  info.blocksize = AUSIZ;
  info.number_of_blocks = info.buffer_size / AUSIZ;

  if ((info.audio_fd = open(AUDIO_DEVICE, O_WRONLY)) == -1)
    errdie("Cannot open audio device");
}

void set_audio_parameters()
{
  audio_info_t auinfo;

  if ((info.channels < 1) || (info.channels > 2))
    if (!info.force)
      errdie("Invalid number of channels");

#ifdef AUDIO_INITINFO
  AUDIO_INITINFO(&auinfo);
#else
  if (ioctl(info.audio_fd, AUDIO_GETINFO, &auinfo) < 0)
    errdie("Unable to get audio info");
#endif

  auinfo.play.precision = info.bits;
  auinfo.play.encoding = info.encoding;
  auinfo.play.channels = info.channels;
  auinfo.play.sample_rate = info.speed;
  if (ioctl(info.audio_fd, AUDIO_SETINFO, &auinfo) < 0)
    die("Unable to set audio parameters");

}

void sync_audio(void)
{
  if (ioctl(info.audio_fd, AUDIO_DRAIN, NULL) < 0)
    errdie("Audio sync failed");
}

void reset_audio(void)
{
  if (ioctl(info.audio_fd, I_FLUSH, FLUSHW) < 0)
    errdie("Audio reset failed");
}

void post_audio(void)
{
  /* This should force anything in the stream to be played. */
  write(info.audio_fd, (char *)NULL, 0);
}

void close_audio(void)
{
  if (info.audio_fd != -1) {
    close(info.audio_fd);
    info.audio_fd = -1;
  }
}

